@@ -311,16 +311,17 @@ main (int argc, char **argv)
 			printf("%s", buffer);
 		}
 
-#  ifdef USE_OPENSSL
-		  if ( check_cert ) {
+		}
+#endif
+
+#ifdef USE_OPENSSL
+		if ( (use_ssl || use_starttls) && check_cert ) {
                     result = np_net_ssl_check_cert(days_till_exp_warn, days_till_exp_crit);
 		    smtp_quit();
 		    my_close();
 		    return result;
 		  }
-#  endif /* USE_OPENSSL */
-		}
-#endif
+#endif /* USE_OPENSSL */
 
 		if (send_mail_from) {
 		  my_send(cmd_str, strlen(cmd_str));
@@ -583,7 +584,7 @@ process_arguments (int argc, char **argv)
 					     _("Could not realloc() units [%d]\n"), ncommands);
 			}
 			commands[ncommands] = (char *) malloc (sizeof(char) * 255);
-			strncpy (commands[ncommands], optarg, 255);
+			strncpy (commands[ncommands], optarg, 254);
 			ncommands++;
 			break;
 		case 'R':									/* server responses */
@@ -595,7 +596,7 @@ process_arguments (int argc, char **argv)
 					     _("Could not realloc() units [%d]\n"), nresponses);
 			}
 			responses[nresponses] = (char *) malloc (sizeof(char) * 255);
-			strncpy (responses[nresponses], optarg, 255);
+			strncpy (responses[nresponses], optarg, 254);
 			nresponses++;
 			break;
 		case 'c':									/* critical time threshold */
@@ -648,6 +649,7 @@ process_arguments (int argc, char **argv)
 #else
 			usage (_("SSL support not available - install OpenSSL and recompile"));
 #endif
+			break;
 		case 's':
 		/* ssl */
 			use_ssl = TRUE;
